## Font Info

The Font Info window contains general information about a Glyphs file, such as the font family name, the masters, the exported font instances, and the OpenType features.
Open Font Info by choosing “File” → “Font Info…” (Cmd-I) or click the Info i button located in the top-left of the main window.

Font Info is split into multiple tabs.
The “Font”, “Masters”, and “Exports” tabs control the font metadata with rows of fields.
Click the plus  button to the right of the bold headings to add additional fields.
Click the minus  button to the right of a row to delete it.
For rows with a plus button to the right, hold down the Option key to reveal the minus button.
Alternatively, click a row to select it, then delete it by pressing Cmd-Delete.

Some fields can be localized into multiple languages.
These display a language menu and a plus  button to the right of the field.
Click the plus button to add additional localizations and pick the respective language from the languages menu.

Select one or multiple rows by Command-clicking and copy them by choosing “Edit” → “Copy” (Cmd-C).
Paste rows with “Edit” → “Paste” (Cmd-V).